const Router = require("koa-router");
const staticRouter = require("./controllers/static-router");
const system = require("./controllers/system");
const user = require("./controllers/user");
const enterprise = require("./controllers/enterprise");
const role = require("./controllers/role");
const life = require("./controllers/life-no");
const goods = require("./controllers/goods");
const activity = require("./controllers/activity");
const withdrawal = require("./controllers/withdrawal");
const groupmeal = require("./controllers/groupmeal");
const qr_code = require("./controllers/qr-code");
const relay = require("./controllers/relay");
const tag = require("./controllers/tag");
const business_circle = require("./controllers/business_circle");

const router = Router();
const API_VERSION = "/api/v1";

router.get(/^\/op.*/, staticRouter.index);

router.get(`${API_VERSION}/qr_code`, qr_code.gen_qr_code);
router.get(`${API_VERSION}/fetch_user`, system.fetch_user);
router.get(`${API_VERSION}/user/:type`, user.query);
router.post(`${API_VERSION}/J_login`, system.J_login);
router.post(`${API_VERSION}/YD_login`, system.YD_login);
router.get(`${API_VERSION}/users`, user.user_list);
router.get(`${API_VERSION}/users/detail`, user.user_detail);
router.post(`${API_VERSION}/users/edit`, user.user_edit);
router.post(`${API_VERSION}/users/new`, user.user_new);
router.post(`${API_VERSION}/users/getPhoneWechat`, user.getPhoneWechat);
router.post(`${API_VERSION}/users/couponGrant`, user.couponGrant);

router.post(`${API_VERSION}/merchant/authority/role_list`, role.getRole_list);
router.post(`${API_VERSION}/merchant/authority/add_role`, role.getAdd_role);
router.post(`${API_VERSION}/merchant/authority/update_role`, role.getUpdate_role);
router.post(`${API_VERSION}/merchant/authority/get_role_list`, role.getAll_role_list);
router.post(`${API_VERSION}/merchant/authority/get_role_info`, role.get_role_info);
router.post(`${API_VERSION}/merchant/authority/delete_role`, role.getDelete_role);
/* 企业认证 */
router.post(`${API_VERSION}/certification`, enterprise.auditList);
router.post(`${API_VERSION}/send_code`, enterprise.sendCode);
router.post(`${API_VERSION}/check_code`, enterprise.checkCode);
router.post(`${API_VERSION}/get_record_info`, enterprise.getRecordInfo);
router.post(`${API_VERSION}/get_log`, enterprise.getLog);
router.post(`${API_VERSION}/audit`, enterprise.postAudit);
router.post(`${API_VERSION}/business`, enterprise.postBusiness);
router.post(`${API_VERSION}/op_commit`, enterprise.opCommit);
router.post(`${API_VERSION}/op_business_update`, enterprise.opBusinessUpdate);

/* 商品管理 */
router.get(`${API_VERSION}/get_goods_category_list`, goods.getCategoryList);
router.get(`${API_VERSION}/goods/background/get_goods_list`, goods.getList);
router.post(`${API_VERSION}/goods/background/online`, goods.putOnline);
router.post(`${API_VERSION}/goods/background/offline`, goods.putOffline);
router.post(`${API_VERSION}/goods/background/putOnlineSite`, goods.putOnlineSite);
router.get(`${API_VERSION}/goods/background/get_goods_info`, goods.getGoodsInfo);
router.post(`${API_VERSION}/goods/background/audit_pass`, goods.postSuccess);
router.post(`${API_VERSION}/goods/background/check_goods_name`, goods.checkGoodsName);
router.post(`${API_VERSION}/goods/background/audit_reject`, goods.auditReject);
router.get(`${API_VERSION}/shop/background/shop_list`, goods.getShopsList);
router.post(`${API_VERSION}/shop/background/add_shop`, goods.addShop);
router.post(`${API_VERSION}/goods/background/edit_goods`, goods.editGoods);

//  营销活动
router.post(`${API_VERSION}/get_marketing_list`, goods.getMarketingList);
router.post(`${API_VERSION}/get_addmarketing_list`, goods.getAddMarketingList);
router.post(`${API_VERSION}/get_find_goods_list`, goods.getFindGoodsList);
router.post(`${API_VERSION}/get_marketing_info`, goods.getMarketingInfo);
router.post(`${API_VERSION}/update_marketing_list`, goods.updateMarketingList);
router.post(`${API_VERSION}/otaList`, goods.otaList);
//商家管理
router.post(`${API_VERSION}/addOta`, goods.addOta);
router.post(`${API_VERSION}/deleteOta`, goods.deleteOta);
router.post(`${API_VERSION}/updateOta`, goods.updateOta);
router.post(`${API_VERSION}/undeleteOta`, goods.undeleteOta);
router.post(`${API_VERSION}/coloneList`, goods.coloneList);
router.post(`${API_VERSION}/coloneApplyList`, goods.coloneApplyList);
router.post(`${API_VERSION}/colonelAudit`, goods.colonelAudit);
router.post(`${API_VERSION}/colonelApplyPoint`, goods.colonelApplyPoint);
router.post(`${API_VERSION}/colonelAddApplyPoint`, goods.colonelAddApplyPoint);
router.post(`${API_VERSION}/yingxiaoList`, goods.yingxiaoList);
router.post(`${API_VERSION}/addAmount`, goods.addAmount);
router.get(`${API_VERSION}/capitalPoolDetail`, goods.capitalPoolDetail);
router.post(`${API_VERSION}/toogleYingxiaoOnlineStatus`, goods.toogleYingxiaoOnlineStatus);
router.post(`${API_VERSION}/yingxiaoConfig`, goods.yingxiaoConfig);
router.post(`${API_VERSION}/yingxiaoSaveConfig`, goods.yingxiaoSaveConfig);

//生活号
router.post(`${API_VERSION}/merchant/lifeinner/life_info`, life.get_life_info);
router.get(`${API_VERSION}/merchant/lifeinner/life_list`, life.get_life_list);
//用户
router.post(`${API_VERSION}/merchant/authority/get_user_info`, user.getUser_detail);
// 后台运营管理
router.get(`${API_VERSION}/marketing/background/marketing_list`, activity.getActivityList);
router.get(`${API_VERSION}/order/background/pindan_marketing_info_data_statistics`, activity.checkActivityDetailInfo);
router.post(`${API_VERSION}/goods/background/edit_goods`, activity.editGoodsDetail);
router.post(`${API_VERSION}/marketing/background/update_marketing_online_status`, activity.updateActivity);
router.post(`${API_VERSION}/marketing/background/marketing_info`, activity.checkActivityDetail);
//
router.get(`${API_VERSION}/marketing/background/take_place_list`, activity.getPlaceList);
router.post(`${API_VERSION}/marketing/background/add_take_place`, activity.addPlace);
router.post(`${API_VERSION}/marketing/background/delete_take_place`, activity.deletePlace);
router.get(`${API_VERSION}/goods/background/ota_list`, activity.getBusinessList);
router.post(`${API_VERSION}/goods/background/add_goods`, activity.addGoods);
router.get(`${API_VERSION}/goods/background/pindan_goods`, activity.pindanGoods);
router.get(`${API_VERSION}/goods/background/marketing_goods_info`, activity.markGoodsInfo);
router.post(`${API_VERSION}/goods/background/edit_activity_goods`, activity.editGoods);
router.post(`${API_VERSION}/marketing/background/add_marketing`, activity.addMarketing);
router.get(`${API_VERSION}/bp/copyMarketing`, activity.copyMarketing);
router.post(`${API_VERSION}/marketing/background/marketing_info`, activity.marketingInfo);
router.post(`${API_VERSION}/marketing/background/update_marketing`, activity.updateMarketing);

// 团餐运营--配送
router.post(`${API_VERSION}/order/deliverer/list_day_deliverer_conf`, groupmeal.getList);
router.post(`${API_VERSION}/order/deliverer/list_day_deliverer`, groupmeal.getDelivererList);
router.post(`${API_VERSION}/order/deliverer/add_deliverer`, groupmeal.getAddDeliverer);
router.post(`${API_VERSION}/order/deliverer/save_day_deliverer`, groupmeal.getSaveDeliverer);

// 老订单管理
router.get(`${API_VERSION}/order/oldbackground/order_list`, groupmeal.getOrderList);
router.get(`${API_VERSION}/order/oldbackground/marketing_list`, groupmeal.getMarketingList);
router.get(`${API_VERSION}/order/oldbackground/goods_list`, groupmeal.getGoodsList);
router.get(`${API_VERSION}/order/oldbackground/sub_shop_list`, groupmeal.getSubShopList);
router.get(`${API_VERSION}/order/oldbackground/order_export`, groupmeal.orderExport);
router.get(`${API_VERSION}/order/oldbackground/order_print`, groupmeal.orderPrint);
router.get(`${API_VERSION}/order/oldbackground/order_item_list`, groupmeal.orderItemList);
router.get(`${API_VERSION}/order/oldbackground/order_refund_reject`, groupmeal.orderRefundReject);
router.post(`${API_VERSION}/order/oldbackground/order_refund`, groupmeal.orderRefund);
router.post(`${API_VERSION}/order/deliverer/build_plan`, groupmeal.getDeliveryRoutes); //下载配送路线 -lh
router.post(`${API_VERSION}/order/deliverer/plan_down_log`, groupmeal.getEmailRecords); // 查看邮件记录 -lh

// 新订单管理
router.get(`${API_VERSION}/order/background/order_list`, groupmeal.newGetOrderList);
router.get(`${API_VERSION}/order/background/order_condition_marketing_list`, groupmeal.newGetMarketingList);
router.get(`${API_VERSION}/order/background/order_condition_goods_list`, groupmeal.newGetGoodsList);
router.get(`${API_VERSION}/order/background/order_condition_take_place_list`, groupmeal.newGetSubShopList);
router.get(`${API_VERSION}/order/background/order_export`, groupmeal.newOrderExport);
router.get(`${API_VERSION}/order/background/order_print`, groupmeal.newOrderPrint);
router.get(`${API_VERSION}/order/background/order_item_list`, groupmeal.newOrderItemList);
router.get(`${API_VERSION}/order/background/order_refund_reject`, groupmeal.newOrderRefundReject);
router.post(`${API_VERSION}/order/background/order_refund`, groupmeal.newOrderRefund);

// 钱包提现审核
router.get(`${API_VERSION}/get_withdrawal_apply_list`, withdrawal.getApplyList);
router.post(`${API_VERSION}/get_withdrawal_black_list`, withdrawal.getBlackList);
router.post(`${API_VERSION}/get_withdraw_audit`, withdrawal.getWithdrawAudit);
router.post(`${API_VERSION}/get_freezing_fund`, withdrawal.getFreezingFund);
router.get(`${API_VERSION}/get_apply_detail`, withdrawal.getApplyDetail);
// 钱包账户
router.get(`${API_VERSION}/get_account_list`, withdrawal.getAccountList);
router.get(`${API_VERSION}/get_record_list`, withdrawal.getRecordList);
router.post(`${API_VERSION}/get_account_black_list`, withdrawal.getAccountBlackList);
router.post(`${API_VERSION}/get_reblack_list`, withdrawal.getReblackList);
router.get(`${API_VERSION}/get_wallet_account_status`, withdrawal.getWalletAccountStatus);
router.post(`${API_VERSION}/reset_wallet_account_status`, withdrawal.resetAccountStatus);

// 图片上传
router.post(`${API_VERSION}/relay/ks3api_upload`, relay.uploadPic);
router.get(`${API_VERSION}/relay/order_export`, relay.orderExport);
router.get(`${API_VERSION}/relay/old_order_export`, relay.oldOrderExport);

// 分类
router.get(`${API_VERSION}/marketing/background/tag_edit`, tag.edit);
router.get(`${API_VERSION}/marketing/background/tag_list`, tag.list);
router.get(`${API_VERSION}/marketing/background/tag_delete`, tag.delete);

// 分类
router.get(`${API_VERSION}/marketing/background/business_circle_edit`, business_circle.edit);
router.get(`${API_VERSION}/marketing/background/business_circle_list`, business_circle.list);
router.get(`${API_VERSION}/marketing/background/business_circle_delete`, business_circle.delete);

module.exports = router;
